#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
# @Time    : 2023/05/01 00:27:19
# @Author  : 橙橙橙心滴
# @File    : replacement.py
'''

import io
import os
from contextlib import contextmanager

from aligo.core.Auth import Auth
from dynaconf.vendor.dotenv.compat import StringIO
from dynaconf.vendor.dotenv.main import DotEnv
from loguru import logger


class ReplaceMent:
    def __init__(self) -> None:
        pass

    @contextmanager
    def new_get_stream(self):
        A = self
        if isinstance(A.dotenv_path, StringIO): yield A.dotenv_path
        elif os.path.isfile(A.dotenv_path):
            with io.open(A.dotenv_path, encoding='utf8') as B:
                yield B
        else:
            if A.verbose:
                logger.info(
                    'Python-dotenv could not find configuration file %s.',
                    A.dotenv_path or '.env')
            yield StringIO('')






#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
# @Time    : 2023/04/28 15:17:09
# @Author  : 橙橙橙心滴
# @File    : check.py
'''

import threading
import time

from evina import douyin
from evina import douyu

from evina import config


class Evina(config.Arg, config.Env):
    def __init__(self) -> None:

        super().__init__()
        for start in self.dict:
            if start == 'douyu':
                for url, name in self.dict[start].items():
                    if 'http' in url and not url.endswith('/'):
                        url = url.rsplit('/', 1)[1]
                    if not self.check(url):
                        threading.Thread(target=douyu.Douyu,
                                         args=(url, name, self.conf.settings,
                                               self.default.settings),
                                         name=url).start()
            if start == 'douyin':
                for url, name in self.dict[start].items():
                    if not self.check(str(url)):
                        threading.Thread(target=douyin.Douyin,
                                         args=(name, self.conf.settings,
                                               self.default.settings, url),
                                         name=url).start()

    def check(self, name):
        for thread in threading.enumerate():
            if name == thread.name:
                return True
        return False


def start():
    while True:
        sleep = config.Conf().conf.settings.sleep
        Evina()
        time.sleep(sleep)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
# @Time    : 2023/04/27 16:28:57
# @Author  : 橙橙橙心滴
# @File    : alipan.py
'''

from aligo import Aligo


class Backup:
    def __init__(self, local_file, ali_file) -> None:
        self.ali = Aligo()
        self.folder = self.ali.get_folder_by_path(ali_file)
        if self.folder == None:
            self.ali.create_folder(ali_file)
            self.folder = self.ali.get_folder_by_path(ali_file)
        self.ali.sync_folder(local_folder=local_file,
                             remote_folder=self.folder.file_id)

    def alidown(self):
        pass


# Backup('E:\\python\\douyu_ffmpeg\\__pycache__','录播/aaa/__pycache__')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
# @Time    : 2023/04/25 15:40:14
# @Author  : 橙橙橙心滴
# @File    : config.py
'''

import argparse
import os
import sys

from aligo import Aligo
from dynaconf import Dynaconf
from loguru import logger

from evina import replacement


class Conf:
    def __init__(self) -> None:
        replacement.DotEnv._get_stream = replacement.ReplaceMent.new_get_stream
        conf_file = os.path.join(
            os.path.abspath(os.path.join(os.path.dirname(__file__))),
            'disposition', 'config.conf')
        evina_file = os.path.join(
            os.path.abspath(os.path.join(os.path.dirname(__file__))),
            'disposition', 'evina.conf')

        parse = argparse.ArgumentParser()
        parse.add_argument('--start', '-s', nargs=1, help='选择需要录制的平台。')
        parse.add_argument('--url', '-u', nargs='*', help='需要录制的直播间URL/ID。')
        parse.add_argument('--name', '-n', nargs='*', help='自定义文件夹名称')
        self.arg = parse.parse_args()

        self.default = Dynaconf(envvar_prefix='evina',
                                load_dotenv=True,
                                dotenv_path=conf_file,
                                dotenv_override=False)

        self.conf = Dynaconf(envvar_prefix='evina',
                             load_dotenv=True,
                             dotenv_path=conf_file,
                             dotenv_override=True)

        self.evina_douyu = Dynaconf(envvar_prefix='douyu',
                                    load_dotenv=True,
                                    dotenv_path=evina_file,
                                    dotenv_override=True)

        self.evina_douyin = Dynaconf(envvar_prefix='douyin',
                                     load_dotenv=True,
                                     dotenv_path=evina_file,
                                     dotenv_override=True)

        replacement.Auth._EMAIL_USER = self.default.settings.email_user
        replacement.Auth._EMAIL_PASSWORD = self.default.settings.email_password
        email_host = self.default.settings.email_user.split('@')[1].split('.')
        replacement.Auth._EMAIL_HOST = 'smtp.{}.{}'.format(
            email_host[0], email_host[1])
        Aligo(email=(self.default.settings.email_user, '阿里云盘登录二维码验证'))


class Arg(Conf):
    def __init__(self) -> None:
        super().__init__()
        if self.arg.start != None:
            self.start = self.arg.start[0]
            if self.arg.url != None:
                self.dict = {}
                self.dict[self.start] = {}
                if self.arg.name != None:
                    if len(self.arg.url) == len(self.arg.name):
                        for num in range(len(self.arg.url)):
                            self.dict[self.start][
                                self.arg.url[num]] = self.arg.name[num]
                    else:
                        logger.warning('url和name参数不一致!!')
                        sys.exit()
                    logger.info('程序开始执行')
                    for url, name in self.dict[self.start].items():
                        logger.info('平台 - {} | ID/URL - {} | name - {}'.format(
                            self.arg.start[0], url, name))
                else:
                    logger.info('未定义名称，使用直播间默认名称')
                    logger.info('程序开始执行')
                    for url in self.arg.url:
                        self.dict[self.start][url] = None
                        logger.info('平台:{}--ID/URL:{}'.format(
                            self.arg.start[0], url))
            else:
                logger.warning('URL/ID定义错误!!')
                sys.exit()


class Env(Conf):
    def __init__(self) -> None:
        super().__init__()
        if self.arg.start == None:
            self.dict = {}
            try:
                self.evina_douyin.url
            except:
                self.evina_douyin.url = None
            try:
                self.evina_douyu.url
            except:
                self.evina_douyu.url = None
            self.dict = {}
            if self.evina_douyin.url != None:
                self.dict['douyin'] = {}
                for key, value in self.evina_douyin.url.items():
                    self.dict['douyin'][str(value).strip()] = None
            if self.evina_douyu.url != None:
                self.dict['douyu'] = {}
                for key, value in self.evina_douyu.url.items():
                    self.dict['douyu'][str(value).strip()] = None
            logger.info('程序开始执行')
            for start in self.dict:
                for url, name in self.dict[start].items():
                    logger.info('平台 - {} | ID/URL - {}'.format(start, url))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
# @Time    : 2023/04/27 21:54:54
# @Author  : 橙橙橙心滴
# @File    : setup.py
'''

from setuptools import find_packages, setup

setup(name='evina',
      author='Ezong',
      version='1.0.6',
      packages=find_packages(),
      include_package_data=True,
      install_requires=['aligo', 'dynaconf', 'Faker', 'loguru', 'paramiko'],
      entry_points={'console_scripts': ['evina=evina.evina:start']})



#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
# @Time    : 2023/04/26 15:45:13
# @Author  : 橙橙橙心滴
# @File    : douyu.py
'''

import datetime
import json
import os
import random
import re
import shutil
import subprocess
import sys
import threading
import time

import requests
from faker import Faker
from loguru import logger

from evina import alipan, ssh


class Douyu:
    def __init__(self, rid, name, settings, default_settings):
        logger.info('线程创建成功 | 线程名 - {} | PID - {}'.format(
            threading.current_thread().name,
            threading.current_thread().ident))
        self.settings = settings
        self.default_settings = default_settings
        self.open = self.default_settings.open
        self.name = name
        self.rid = rid
        self.ua = Faker(locale="zh_CN").user_agent()
        try:
            self.api()
        except:
            self.data = self.js()
            self.rea_rid()

    def api(self):
        url = 'https://web.sinsyth.com/lxapi/douyujx.x?rid={}'.format(self.rid)
        response = requests.get(url=url)
        self.response = json.loads(response.text)
        if self.response['state'] == 'NO':
            logger.info('斗鱼直播间 - {} | 暂未开播'.format(self.rid))
        if self.response['state'] == 'SUCCESS':
            if self.name == None:
                filename = self.response['Rendata']['data']['nickname']
            else:
                filename = self.name
            # time = str(datetime.datetime.now().strftime('%Y-%m-%d-%H-%M-%S'))
            time = datetime.datetime.now().ctime().replace(':', '-')
            if 'FILE' in self.default_settings.keys() and self.default_settings.file != '':
                file = os.path.join(self.default_settings.file, 'download', '斗鱼录播',
                                    filename, time)
            else:
                file = os.path.join(os.getcwd(), 'download', '斗鱼录播', filename,
                                    time)
            ali_file = os.path.join('录播', '斗鱼录播', filename,
                                    time).replace('\\', '/')
            if not os.path.exists(file):
                os.makedirs(file)
            link = self.response['Rendata']['link']
            f = open('{}/直播源.txt'.format(file), mode='w', encoding='utf8')
            f.write(link)
            f.close()
            logger.info('斗鱼直播间 - {} | 源地址为 - {}'.format(self.rid, link))
            if self.open == False:
                logger.info('斗鱼直播间 - {} - {} | 已成功保存直播源地址到文件'.format(
                    filename, self.rid))

            if self.open:
                logger.info('斗鱼直播间 - {} - {} 开始录制'.format(filename, self.rid))
                if self.default_settings.docker == False:
                    subout = subprocess.run(
                        "ffmpeg -i " + '"{}"'.format(link) +
                        " -c:a copy -c:v copy -bsf:a aac_adtstoasc -threads {} -preset {} -f {}  -f segment -segment_time {} -strftime 1 "
                        .format(str(self.settings.thread),
                                self.settings.preset, self.settings.scheme,
                                str(self.settings.time)) +
                        '"{}"'.format(
                            os.path.join(file, '%Y-%m-%d-%H-%M-%S.ts')))
                    logger.info(subout)
                if self.default_settings.docker == True:
                    ssh.Ssh(link, os.path.join(file, '%Y-%m-%d-%H-%M-%S.ts'),
                            self.settings)
                    alipan.Backup(local_file=file, ali_file=ali_file)
                    shutil.rmtree(
                        os.path.join(
                            os.path.abspath(
                                os.path.join(os.path.dirname(__file__), '..')),
                            'download', '斗鱼录播', filename))

    def js(self):
        file = os.path.join(
            os.path.dirname(__file__),
            str(datetime.datetime.now()).replace(':', '-') + '.js')
        jstime = str(int(time.time()))
        did = '10000000000000000000000000001501'
        url = 'https://www.douyu.com/{}'.format(self.rid)
        response = requests.get(url=url)
        try:
            self.rid = re.findall(r'ROOM.room_id =(\d+)', response.text,
                                  re.S)[0]
        except:
            self.rid = re.findall(r'ROOM.room_id = (\d+)', response.text,
                                  re.S)[0]
        jsdate = re.findall(
            r'<script type="text/javascript">.*?var vdwdae325w_64we = .*?;(.*?)</script>',
            response.text, re.S)[0]
        # js = 'module.paths.push("D:/node/node_modules");const CryptoJS = require("crypto-js");' + jsdate + \
        #     "let arguments=process.argv.splice(2).join('').split(',');for(var i = 0; i < arguments.length; i++) {}console.log(ub98484234(arguments[0],arguments[1],arguments[2]))"
        js = 'module.paths.push("{}");const CryptoJS = require("crypto-js");'.format(self.default_settings.node_modules) + jsdate + \
            "let arguments=process.argv.splice(2).join('').split(',');for(var i = 0; i < arguments.length; i++) {}console.log(ub98484234(arguments[0],arguments[1],arguments[2]))"
        js = js.replace(';', ';\n').replace('}', '}\n')
        f = open(file=file, mode='w', encoding='utf8')
        f.write(js)
        f.close()
        # thenum = os.popen('{} "{}" {},{},{}'.format(os.path.join('D:\\', 'node', 'node.exe'), file, self.rid, did, jstime)).read().replace('\n', '')
        thenum = os.popen(
            '{} "{}" {},{},{}'.format(self.default_settings.nodejs, file, self.rid,
                                      did, jstime)).read().replace('\n', '')
        dict = {
            'cdn': '',
            'rate': '-1',
            'iar': '1',
            'ive': '0',
            'hevc': '0',
            'fa': '0'
        }
        for date in thenum.split('&'):
            dict[date.split('=')[0]] = date.split('=')[1]
        os.remove(file)
        return dict

    def rea_rid(self):
        time = datetime.datetime.now().ctime().replace(':', '-')
        url = 'https://www.douyu.com/lapi/live/getH5Play/{}'.format(self.rid)
        headers = {
            'accept':
            'application/json, text/plain, */*',
            'accept-language':
            'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
            'origin':
            'https://www.douyu.com',
            'referer':
            'https://www.douyu.com/topic/pubg-3yhd?rid={}'.format(self.rid),
            'user-agent':
            self.ua
        }
        response = requests.post(url=url, headers=headers, data=self.data)
        if response.status_code != 200:
            logger.info('斗鱼直播间 - {} | 暂未开播'.format(self.rid))
            sys.exit()
        data = json.loads(response.text)
        if '房间未开播' in data.values():
            logger.info('斗鱼直播间 - {} | 暂未开播'.format(self.rid))
            sys.exit()
        rtmp_url = data['data']['rtmp_url']
        rtmp_live = data['data']['rtmp_live']
        rea_rid = rtmp_live.split('?')[0]
        http = os.path.join(random.choice(['http://hdltc1.douyucdn.cn/live', 'http://hw-tct.douyucdn.cn/live']))  \
            + '/' + rea_rid
        if self.name == None:
            name = self.get_name()
        else:
            name = self.name
        if 'FILE' in self.default_settings.keys() and self.default_settings.file != '':
            file = os.path.join(self.default_settings.file, 'download', '斗鱼录播', name,
                                time)
        else:
            file = os.path.join(os.getcwd(), 'download', '斗鱼录播', name, time)
        ali_file = os.path.join('录播', '斗鱼录播', name, time).replace('\\', '/')
        if not os.path.exists(file):
            os.makedirs(file)
        f = open(file=os.path.join(file, '直播源.txt'), mode='w', encoding='utf8')
        f.write(http)
        f.close()
        logger.info('斗鱼直播间 - {} - {} | 源地址为 - {}'.format(name, self.rid, http))
        if self.open == False:
            logger.info('已成功保存直播源地址到文件')
        if self.open:
            logger.info('斗鱼直播间 - {} - {} 开始录制'.format(name, self.rid))
            if self.default_settings.docker == False:
                subout = subprocess.run(
                    "ffmpeg -i " + '"{}"'.format(http) +
                    " -c:a copy -c:v copy -bsf:a aac_adtstoasc -threads {} -preset {} -f {}  -f segment -segment_time {} -strftime 1 "
                    .format(str(self.settings.thread), self.settings.preset,
                            self.settings.scheme, str(self.settings.time)) +
                    '"{}"'.format(os.path.join(file, '%Y-%m-%d-%H-%M-%S.ts')))
                logger.info(subout)
            if self.default_settings.docker == True:
                ssh.Ssh(http, os.path.join(file, '%Y-%m-%d-%H-%M-%S.ts'),
                        self.settings)
                alipan.Backup(local_file=file, ali_file=ali_file)
                shutil.rmtree(
                    os.path.join(
                        os.path.abspath(
                            os.path.join(os.path.dirname(__file__), '..')),
                        'download', '斗鱼录播', name))

    def get_name(self):
        url = 'https://www.douyu.com/betard/{}'.format(self.rid)
        headers = {
            'accept':
            'application/json, text/plain, */*',
            'accept-language':
            'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
            'referer':
            'https://www.douyu.com/topic/pubg-3yhd?rid={}'.format(self.rid),
            'user-agent':
            self.ua
        }
        response = requests.get(url=url, headers=headers).text
        data = json.loads(response)
        name = data['room']['owner_name']
        return name